summaryrefslogtreecommitdiff
path: root/arch/x86/coco
diff options
context:
space:
mode:
Diffstat (limited to 'arch/x86/coco')
-rw-r--r--arch/x86/coco/tdx/debug.c26
-rw-r--r--arch/x86/coco/tdx/tdx.c8
2 files changed, 17 insertions, 17 deletions
diff --git a/arch/x86/coco/tdx/debug.c b/arch/x86/coco/tdx/debug.c
index 28990c2ab0a1..8e477db4ce0a 100644
--- a/arch/x86/coco/tdx/debug.c
+++ b/arch/x86/coco/tdx/debug.c
@@ -7,21 +7,21 @@
#include <linux/printk.h>
#include <asm/tdx.h>
-#define DEF_TDX_ATTR_NAME(_name) [TDX_ATTR_##_name##_BIT] = __stringify(_name)
+#define DEF_TDX_TD_ATTR_NAME(_name) [TDX_TD_ATTR_##_name##_BIT] = __stringify(_name)
static __initdata const char *tdx_attributes[] = {
- DEF_TDX_ATTR_NAME(DEBUG),
- DEF_TDX_ATTR_NAME(HGS_PLUS_PROF),
- DEF_TDX_ATTR_NAME(PERF_PROF),
- DEF_TDX_ATTR_NAME(PMT_PROF),
- DEF_TDX_ATTR_NAME(ICSSD),
- DEF_TDX_ATTR_NAME(LASS),
- DEF_TDX_ATTR_NAME(SEPT_VE_DISABLE),
- DEF_TDX_ATTR_NAME(MIGRATABLE),
- DEF_TDX_ATTR_NAME(PKS),
- DEF_TDX_ATTR_NAME(KL),
- DEF_TDX_ATTR_NAME(TPA),
- DEF_TDX_ATTR_NAME(PERFMON),
+ DEF_TDX_TD_ATTR_NAME(DEBUG),
+ DEF_TDX_TD_ATTR_NAME(HGS_PLUS_PROF),
+ DEF_TDX_TD_ATTR_NAME(PERF_PROF),
+ DEF_TDX_TD_ATTR_NAME(PMT_PROF),
+ DEF_TDX_TD_ATTR_NAME(ICSSD),
+ DEF_TDX_TD_ATTR_NAME(LASS),
+ DEF_TDX_TD_ATTR_NAME(SEPT_VE_DISABLE),
+ DEF_TDX_TD_ATTR_NAME(MIGRATABLE),
+ DEF_TDX_TD_ATTR_NAME(PKS),
+ DEF_TDX_TD_ATTR_NAME(KL),
+ DEF_TDX_TD_ATTR_NAME(TPA),
+ DEF_TDX_TD_ATTR_NAME(PERFMON),
};
#define DEF_TD_CTLS_NAME(_name) [TD_CTLS_##_name##_BIT] = __stringify(_name)
diff --git a/arch/x86/coco/tdx/tdx.c b/arch/x86/coco/tdx/tdx.c
index 7b2833705d47..186915a17c50 100644
--- a/arch/x86/coco/tdx/tdx.c
+++ b/arch/x86/coco/tdx/tdx.c
@@ -238,14 +238,14 @@ static void __noreturn tdx_panic(const char *msg)
*
* TDX 1.0 does not allow the guest to disable SEPT #VE on its own. The VMM
* controls if the guest will receive such #VE with TD attribute
- * TDX_ATTR_SEPT_VE_DISABLE.
+ * TDX_TD_ATTR_SEPT_VE_DISABLE.
*
* Newer TDX modules allow the guest to control if it wants to receive SEPT
* violation #VEs.
*
* Check if the feature is available and disable SEPT #VE if possible.
*
* If the TD is allowed to disable/enable SEPT #VEs, the TDX_ATTR_SEPT_VE_DISABLE
* attribute is no longer reliable. It reflects the initial state of the
* control for the TD, but it will not be updated if someone (e.g. bootloader)
* changes it before the kernel starts. Kernel must check TDCS_TD_CTLS bit to
@@ -254,14 +254,14 @@ static void __noreturn tdx_panic(const char *msg)
static void disable_sept_ve(u64 td_attr)
{
const char *msg = "TD misconfiguration: SEPT #VE has to be disabled";
- bool debug = td_attr & TDX_ATTR_DEBUG;
+ bool debug = td_attr & TDX_TD_ATTR_DEBUG;
u64 config, controls;
/* Is this TD allowed to disable SEPT #VE */
tdg_vm_rd(TDCS_CONFIG_FLAGS, &config);
if (!(config & TDCS_CONFIG_FLEXIBLE_PENDING_VE)) {
/* No SEPT #VE controls for the guest: check the attribute */
- if (td_attr & TDX_ATTR_SEPT_VE_DISABLE)
+ if (td_attr & TDX_TD_ATTR_SEPT_VE_DISABLE)
return;
/* Relax SEPT_VE_DISABLE check for debug TD for backtraces */
@@ -238,14 +238,14 @@ static void __noreturn tdx_panic(const char *msg)
* Check if the feature is available and disable SEPT #VE if possible.
*
- * If the TD is allowed to disable/enable SEPT #VEs, the TDX_ATTR_SEPT_VE_DISABLE
+ * If the TD is allowed to disable/enable SEPT #VEs, the TDX_TD_ATTR_SEPT_VE_DISABLE
* attribute is no longer reliable. It reflects the initial state of the
* control for the TD, but it will not be updated if someone (e.g. bootloader)